
IMS Global Learning Consortium Specifications
=============================================

The section contains modules that implement specifications published by the IMS
Global Learning Consortium.  For more information see http://www.imsglobal.org/

Contents:

.. toctree::
   :maxdepth: 2
   
   imscpv1p2
   imsqtiv1p2p1
   imsqtiv2p1
   imsbltiv1p0